@@ -4,7 +4,7 @@ use warnings;
 #
 #
 # XASTIR, Amateur Station Tracking and Information Reporting
-# Copyright (C) 2000-2019 The Xastir Group
+# Copyright (C) 2000-2023 The Xastir Group
 #
 # "ais.pl", a Perl script to connect aisdecoder and Xastir for receiving
 # packets from ships. This script will create a UDP server at localhost:10110
@@ -221,7 +221,7 @@ $log_file = "~/.xastir/logs/ships.log";
     "264" => "Romania",
     "265" => "Sweden",
     "266" => "Sweden",
-    "267" => "Slovak",    # "Slovak Republic"
+    "267" => "Slovakia",    # "Slovak Republic"
     "268" => "San Marino",    # "San Marino (Republic of)"
     "269" => "Switzerland",    # "Switzerland (Confederation of)"
     "270" => "Czech Rep.",    # "Czech Republic"
@@ -321,7 +321,7 @@ $log_file = "~/.xastir/logs/ships.log";
     "445" => "N. Korea",    # "Democratic People's Republic of Korea"
     "447" => "Kuwait",    # "Kuwait (State of)"
     "450" => "Lebanon",
-    "451" => "Kyrgyz Rep.",    # "Kyrgyz Republic"
+    "451" => "Kyrgyzstan",    # "Kyrgyz Republic"
     "453" => "Macao",    # "Macao (Special Administrative Region of China) - China (People's Republic of)"
     "455" => "Maldives",    # "Maldives (Republic of)"
     "457" => "Mongolia",
@@ -331,6 +331,7 @@ $log_file = "~/.xastir/logs/ships.log";
     "466" => "Qatar",    # "Qatar (State of)"
     "468" => "Syria",    # "Syrian Arab Republic"
     "470" => "United Arab Emirates",
+    "471" => "United Arab Emirates",
     "472" => "Tajikistan",    # "Tajikistan (Republic of)"
     "473" => "Yemen",    # "Yemen (Republic of)"
     "475" => "Yemen",    # "Yemen (Republic of)"
@@ -388,7 +389,7 @@ $log_file = "~/.xastir/logs/ships.log";
     "613" => "Cameroon",    # "Cameroon (Republic of)"
     "615" => "Congo",    # "Congo (Republic of the)"
     "616" => "Comoros",    # "Comoros (Union of the)"
-    "617" => "Cabo Verde",    # "Cabo Verde (Republic of)"
+    "617" => "Cape Verde",    # "Cabo Verde (Republic of)"
     "618" => "Crozet Archipelago",    # "Crozet Archipelago - France"
     "619" => "Cte d'Ivoire",    # "Cte d'Ivoire (Republic of)"
     "620" => "Comoros",    # "Comoros (Union of the)"
@@ -447,7 +448,7 @@ $log_file = "~/.xastir/logs/ships.log";
     "740" => "Falkland Is.",    # "Falkland Islands (Malvinas) - United Kingdom of Great Britain and Northern Ireland"
     "745" => "Guiana",    # "Guiana (French Department of) - France"
     "750" => "Guyana",
-    "755" => "Parguay",    # "Paraguay (Republic of)"
+    "755" => "Paraguay",    # "Paraguay (Republic of)"
     "760" => "Peru",
     "765" => "Suriname",    # "Suriname (Republic of)"
     "770" => "Uruguay",    # "Uruguay (Eastern Republic of)"
