@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,24 +34,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-// Needed for Solaris
-#ifdef HAVE_STRINGS_H
-  #include <strings.h>
-#endif  // HAVE_STRINGS_H
-
 #include <ctype.h>
 #include <sys/types.h>
 
-#if TIME_WITH_SYS_TIME
+#if HAVE_SYS_TIME_H
   #include <sys/time.h>
-  #include <time.h>
-#else   // TIME_WITH_SYS_TIME
-  #if HAVE_SYS_TIME_H
-    #include <sys/time.h>
-  #else  // HAVE_SYS_TIME_H
-    #include <time.h>
-  #endif // HAVE_SYS_TIME_H
-#endif  // TIME_WITH_SYS_TIME
+#endif // HAVE_SYS_TIME_H
+#include <time.h>
 
 #include <Xm/XmAll.h>
 
