@@ -1,7 +1,7 @@
 /*
  *
  *
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This file was contributed by Jerry Dunmire, KA6HLD.
  *
@@ -23,7 +23,7 @@
  *
  * This file derived from map_tiger.c which has the following copyrights:
  *    Copyright (C) 1999,2000  Frank Giannandrea
- *    Copyright (C) 2000-2019 The Xastir Group
+ *    Copyright (C) 2000-2023 The Xastir Group
  */
 
 
@@ -42,11 +42,6 @@
 #include <pwd.h>
 #include <errno.h>
 
-// Needed for Solaris
-#ifdef HAVE_STRINGS_H
-  #include <strings.h>
-#endif  // HAVE_STRINGS_H
-
 #include <dirent.h>
 #include <netinet/in.h>
 #include <Xm/XmAll.h>
@@ -83,17 +78,10 @@
 #define CHECKMALLOC(m)  if (!m) { fprintf(stderr, "***** Malloc Failed *****\n"); exit(0); }
 
 #ifdef HAVE_MAGICK
-  #if TIME_WITH_SYS_TIME
+  #if HAVE_SYS_TIME_H
     #include <sys/time.h>
-    #include <time.h>
-  #else   // TIME_WITH_SYS_TIME
-    #if HAVE_SYS_TIME_H
-      #include <sys/time.h>
-    #else  // HAVE_SYS_TIME_H
-      #include <time.h>
-    #endif // HAVE_SYS_TIME_H
-  #endif  // TIME_WITH_SYS_TIME
-  #undef RETSIGTYPE
+  #endif // HAVE_SYS_TIME_H
+  #include <time.h>
   // TVR: "stupid ImageMagick"
   // The problem is that magick/api.h includes Magick's config.h file, and that
   // pulls in all the same autoconf-generated defines that we use.
@@ -436,7 +424,7 @@ static long xastirLat2pixelLat(
 
   // xastir latitude values can exceed +/- 90.0 degrees because
   // the latitude is the extent of the display window. Limit the
-  // OSM latitute to less than +/- 90.0 degrees so that the projection
+  // OSM latitude to less than +/- 90.0 degrees so that the projection
   // calculation does not blow up or return unreasonable values.
   if (lat > ((89.0/180.0) * M_PI))
   {
@@ -555,28 +543,18 @@ static void draw_image(
   // try to reduce the number of colors in an image.
   // This may take some time, so it would be best to do ahead of
   // time if it is a static image.
-#if (MagickLibVersion < 0x0540)
-  if (visual_type == NOT_TRUE_NOR_DIRECT && GetNumberColors(image, NULL) > 128)
-  {
-#else   // MagickLib >= 540
   if (visual_type == NOT_TRUE_NOR_DIRECT && GetNumberColors(image, NULL, except_ptr) > 128)
   {
-#endif  // MagickLib Version
-
     if (image->storage_class == PseudoClass)
     {
-#if (MagickLibVersion < 0x0549)
-      CompressColormap(image); // Remove duplicate colors
-#else // MagickLib >= 0x0549
       CompressImageColormap(image); // Remove duplicate colors
-#endif  // MagickLibVersion < 0x0549
     }
 
     // Quantize down to 128 will go here...
   }
 
 
-#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x0669)
+#if defined(HAVE_GRAPHICSMAGICK)
   pixel_pack = GetImagePixels(image, 0, 0, image->columns, image->rows);
 #else
   pixel_pack = GetAuthenticPixels(image, 0, 0, image->columns, image->rows, except_ptr);
@@ -593,12 +571,8 @@ static void draw_image(
 #else
   index_pack = AccessMutableIndexes(image);
 #endif
-#else
-#if (MagickLibVersion < 0x0669)
-  index_pack = GetIndexes(image);
 #else
   index_pack = GetAuthenticIndexQueue(image);
-#endif
 #endif
   if (image->storage_class == PseudoClass && !index_pack)
   {
@@ -687,7 +661,7 @@ static void draw_image(
 
     scr_y = image_row + offsety;
 
-    // loop over image pixel colums
+    // loop over image pixel columns
     for (image_col = 0; image_col < image->columns; image_col++)
     {
       scr_x = image_col + offsetx;
@@ -788,28 +762,18 @@ static void draw_OSM_image(
   // try to reduce the number of colors in an image.
   // This may take some time, so it would be best to do ahead of
   // time if it is a static image.
-#if (MagickLibVersion < 0x0540)
-  if (visual_type == NOT_TRUE_NOR_DIRECT && GetNumberColors(image, NULL) > 128)
-  {
-#else   // MagickLib >= 540
   if (visual_type == NOT_TRUE_NOR_DIRECT && GetNumberColors(image, NULL, except_ptr) > 128)
   {
-#endif  // MagickLib Version
-
     if (image->storage_class == PseudoClass)
     {
-#if (MagickLibVersion < 0x0549)
-      CompressColormap(image); // Remove duplicate colors
-#else // MagickLib >= 0x0549
       CompressImageColormap(image); // Remove duplicate colors
-#endif  // MagickLibVersion < 0x0549
     }
 
     // Quantize down to 128 will go here...
   }
 
 
-#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x669)
+#if defined(HAVE_GRAPHICSMAGICK)
   pixel_pack = GetImagePixels(image, 0, 0, image->columns, image->rows);
 #else
   pixel_pack = GetAuthenticPixels(image, 0, 0, image->columns, image->rows, except_ptr);
@@ -826,12 +790,8 @@ static void draw_OSM_image(
 #else
   index_pack = AccessMutableIndexes(image);
 #endif
-#else
-#if (MagickLibVersion < 0x0669)
-  index_pack = GetIndexes(image);
 #else
   index_pack = GetAuthenticIndexQueue(image);
-#endif
 #endif
   if (image->storage_class == PseudoClass && !index_pack)
   {
@@ -1076,7 +1036,7 @@ static void draw_OSM_image(
               XSetForeground(XtDisplay(w), gc, my_colors[0].pixel);
             }
             // write the pixel from the map image to the
-            // screen. Strech to a rectangle as needed
+            // screen. Stretch to a rectangle as needed
             // specified by scr_dx and scr_dy.
             (void)XFillRectangle (XtDisplay (w),pixmap,gc,scr_x,scr_y,scr_dx,scr_dy);
           } // check map boundaries in y direction
@@ -1372,7 +1332,7 @@ void draw_OSM_tiles (Widget w,
     canvas->background_color.green = MATTE_GREEN;
     canvas->background_color.blue = MATTE_BLUE;
     canvas->background_color.opacity = MATTE_OPACITY;
-#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x0669)
+#if defined(HAVE_GRAPHICSMAGICK)
     SetImage(canvas, MATTE_OPACITY);
 #else
     SetImageBackgroundColor(canvas);
@@ -1409,7 +1369,7 @@ void draw_OSM_tiles (Widget w,
           if (exception.severity==FileOpenError)
           {
             //fprintf(stderr, "%s NOT available\n", tile_info->filename);
-#if !defined(HAVE_GRAPHICSMAGICK) && (MagickLibVersion > 0x0669)
+#if !defined(HAVE_GRAPHICSMAGICK)
             ClearMagickException(&exception);
 #endif
           }
@@ -1452,7 +1412,7 @@ void draw_OSM_tiles (Widget w,
 
     if (debug_level & 512)
     {
-#if defined(HAVE_GRAPHICSMAGICK) || (MagickLibVersion < 0x0669)
+#if defined(HAVE_GRAPHICSMAGICK)
       DescribeImage(canvas, stderr, 0);
 #else
       IdentifyImage(canvas, stderr, 0);
@@ -1463,7 +1423,7 @@ void draw_OSM_tiles (Widget w,
     draw_OSM_image(w, canvas, &exception, &NWcorner, &SEcorner, osm_zl);
 
     // Display the OpenStreetMap attribution
-    // Just resuse the tile structure rather than creating another.
+    // Just reuse the tile structure rather than creating another.
     xastir_snprintf(tmpString, sizeof(tmpString),
                     "%s/CC_OpenStreetMap.png", get_data_base_dir("maps"));
     strncpy(tile_info->filename, tmpString, MaxTextExtent);
@@ -1517,7 +1477,7 @@ void draw_OSM_tiles (Widget w,
 
 
 /**********************************************************
- * draw_OSM_map() - retreive an image that is the size of the display
+ * draw_OSM_map() - retrieve an image that is the size of the display
  **********************************************************/
 void draw_OSM_map (Widget w,
                    char *filenm,
@@ -1851,11 +1811,7 @@ void draw_OSM_map (Widget w,
   {
     fprintf(stderr,"Image: %s\n", file);
     fprintf(stderr,"Image size %d %d\n", map_image_width, map_image_height);
-#if (MagickLibVersion < 0x0540)
-    fprintf(stderr,"Unique colors = %d\n", GetNumberColors(image, NULL));
-#else // MagickLib < 540
     fprintf(stderr,"Unique colors = %ld\n", GetNumberColors(image, NULL, &exception));
-#endif // MagickLib < 540
     fprintf(stderr,"image matte is %i\n", image->matte);
   } // debug_level & 512
 
