@@ -2,7 +2,7 @@
  *
  * XASTIR, Amateur Station Tracking and Information Reporting
  * Copyright (C) 1999,2000  Frank Giannandrea
- * Copyright (C) 2000-2019 The Xastir Group
+ * Copyright (C) 2000-2023 The Xastir Group
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -37,24 +37,14 @@
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
-#ifdef HAVE_STRING_H
-  #include <string.h>
-#else
-  #include <strings.h>
-#endif
+#include <string.h>
 #include <ctype.h>
 #include <sys/types.h>
 
-#if TIME_WITH_SYS_TIME
+#if HAVE_SYS_TIME_H
   #include <sys/time.h>
-  #include <time.h>
-#else   // TIME_WITH_SYS_TIME
-  #if HAVE_SYS_TIME_H
-    #include <sys/time.h>
-  #else  // HAVE_SYS_TIME_H
-    #include <time.h>
-  #endif // HAVE_SYS_TIME_H
-#endif  // TIME_WITH_SYS_TIME
+#endif // HAVE_SYS_TIME_H
+#include <time.h>
 
 #include "xastir.h"
 #include "main.h"
@@ -649,7 +639,7 @@ void view_all_messages( Widget UNUSED(w), XtPointer UNUSED(clientData), XtPointe
     n++;
 
     option_box = XmCreateRadioBox(my_form,
-                                  "Vew Messages option box",
+                                  "View Messages option box",
                                   args,
                                   n);
 
